"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
const logger_1 = __importDefault(require("./logger"));
class Connection {
    constructor(onMessage, onError, onClose) {
        this.connected = false;
        this.onMessage = onMessage;
        this.onError = onError;
        this.onClose = onClose;
    }
    connect(options) {
        this.ws = new WebSocket(options.url);
        this.ws.binaryType = 'arraybuffer';
        const that = this;
        return new Promise(function (resolve, reject) {
            if (options.timeout !== undefined && options.timeout > 0) {
                that.connectionTimeout = window.setTimeout(function () {
                    if (that.ws.readyState === 0) {
                        console.log("WS connection timeout");
                        that.ws.close();
                    }
                }, options.timeout);
            }
            that.ws.onerror = function (e) {
                if (that.connected) {
                    that.onError(e);
                }
                else {
                    reject(e);
                }
            };
            that.ws.onclose = function (e) {
                if (that.connected) {
                    that.onClose(e);
                }
                else {
                    reject(e);
                }
            };
            that.ws.onopen = function () {
                clearTimeout(that.connectionTimeout);
                let cConfig = {
                    appKey: options.appName,
                    mediaProviders: ["WebRTC"],
                    keepAlive: true,
                    authToken: null,
                    clientVersion: "0.5.28",
                    clientOSVersion: window.navigator.appVersion,
                    clientBrowserVersion: window.navigator.userAgent,
                    custom: options.custom
                };
                //connect to REST App
                that.send("connection", cConfig);
            };
            that.ws.onmessage = function (event) {
                let name;
                let msg;
                if (event.data instanceof Blob) {
                    name = "binaryData";
                }
                else {
                    let obj = JSON.parse(event.data);
                    name = obj.message;
                    msg = obj.data;
                }
                switch (name) {
                    case "ping":
                        that.send("pong", null);
                        break;
                    case "getUserData":
                        that.connected = true;
                        resolve(msg[0]);
                        break;
                    default:
                        that.onMessage(name, msg);
                }
            };
        });
    }
    send(message, data) {
        logger_1.default.log("==>", message, data);
        if (this.ws) {
            this.ws.send(JSON.stringify({
                message: message,
                data: [data]
            }));
        }
    }
    ;
    close() {
        if (this.ws) {
            this.ws.close();
        }
    }
}
exports.Connection = Connection;
//# sourceMappingURL=connection.js.map