export declare enum SfuEvent {
    CONNECTED = "CONNECTED",
    FAILED = "FAILED",
    DISCONNECTED = "DISCONNECTED",
    MESSAGE = "MESSAGE",
    USER_LIST = "USER_LIST",
    USER_CHATS = "USER_CHATS",
    CHAT_LOADED = "CHAT_LOADED",
    NEW_CHAT = "NEW_CHAT",
    CHAT_DELETED = "CHAT_DELETED",
    CHAT_UPDATED = "CHAT_UPDATED",
    MESSAGE_STATE = "MESSAGE_STATE",
    CONTACT_UPDATE = "CONTACT_UPDATE",
    CONTACT_REMOVED = "CONTACT_REMOVED",
    CONTACT_INVITE = "CONTACT_INVITE",
    PUBLIC_CHANNELS = "PUBLIC_CHANNELS",
    USER_CALENDAR = "USER_CALENDAR",
    ACK = "ACK"
}
export declare enum RoomEvent {
    CREATED = "CREATED",
    FAILED = "FAILED",
    ADD_TRACKS = "ADD_TRACKS",
    REMOVE_TRACKS = "REMOVE_TRACKS",
    MESSAGE = "MESSAGE",
    CONTROL_MESSAGE = "CONTROL_MESSAGE",
    JOINED = "JOINED",
    LEFT = "LEFT",
    DETACHED = "DETACHED",
    EVICTED = "EVICTED",
    REMOTE_SDP = "REMOTE_SDP",
    TRACK_QUALITY_STATE = "TRACK_QUALITY_STATE",
    OPERATION_FAILED = "OPERATION_FAILED",
    WAITING_LIST = "SFU_WAITING_LIST",
    WAITING_ROOM_UPDATE = "SFU_WAITING_ROOM_UPDATE",
    MUTE_TRACKS = "MUTE_TRACKS",
    PARTICIPANT_LIST = "PARTICIPANT_LIST",
    ROLE_ASSIGNED = "ROLE_ASSIGNED"
}
export declare enum State {
    NEW = "NEW",
    PENDING = "PENDING",
    CONNECTED = "CONNECTED",
    AUTHENTICATED = "AUTHENTICATED",
    DISCONNECTED = "DISCONNECTED",
    FAILED = "FAILED"
}
export declare enum RoomState {
    NEW = "NEW",
    PENDING = "PENDING",
    JOINED = "JOINED",
    FAILED = "FAILED",
    DISPOSED = "DISPOSED"
}
export declare enum Operations {
    ROOM_CREATE = "ROOM_CREATE",
    ROOM_JOIN = "ROOM_JOIN",
    ROOM_DESTROY = "ROOM_DESTROY",
    SEND_MESSAGE = "SEND_MESSAGE",
    USER_LIST = "USER_LIST",
    USER_CALENDAR = "USER_CALENDAR",
    ADD_CALENDAR_EVENT = "ADD_CALENDAR_EVENT",
    REMOVE_CALENDAR_EVENT = "REMOVE_CALENDAR_EVENT",
    ROOM_UPDATE = "ROOM_UPDATE",
    MUTE_TRACKS = "MUTE_TRACKS",
    ASSIGN_ROLE = "ASSIGN_ROLE",
    SUBSCRIBE_TO_WAITING_PARTICIPANT = "SUBSCRIBE_TO_WAITING_PARTICIPANT",
    UNSUBSCRIBE_FROM_WAITING_PARTICIPANT = "UNSUBSCRIBE_FROM_WAITING_PARTICIPANT",
    MOVE_TO_WAITING_ROOM = "MOVE_TO_WAITING_ROOM",
    CREATE_CHAT = "CREATE_CHAT",
    DELETE_CHAT = "DELETE_CHAT",
    RENAME_CHAT = "RENAME_CHAT",
    LOAD_CHAT = "LOAD_CHAT",
    ADD_MEMBER_TO_CHAT = "ADD_MEMBER_TO_CHAT",
    REMOVE_MEMBER_FROM_CHAT = "REMOVE_MEMBER_FROM_CHAT",
    UPDATE_CHAT_PREFERENCES = "UPDATE_CHAT_PREFERENCES",
    GET_USER_CHATS = "GET_USER_CHATS"
}
export declare enum ParticipantRole {
    OWNER = "OWNER",
    ADMIN = "ADMIN",
    PARTICIPANT = "PARTICIPANT"
}
export declare enum TrackType {
    AUDIO = "AUDIO",
    VIDEO = "VIDEO"
}
export declare enum InternalApi {
    Z_APP = "sfuZClientApp",
    P_APP = "sfuApp",
    DEFAULT_METHOD = "sfuCallback",
    JOIN_ROOM = "joinRoom",
    CREATE_ROOM = "createRoom",
    UPDATE_ROOM_STATE = "updateRoomState",
    DESTROY_ROOM = "destroyRoom",
    LEAVE_ROOM = "leaveRoom",
    CHANGE_QUALITY = "changeQuality",
    AUTHORIZE_WAITING_LIST = "authorizeWaitingList",
    MESSAGE = "SFU_MESSAGE",
    MESSAGE_STATE = "SFU_MESSAGE_STATE",
    USER_LIST = "SFU_USER_LIST",
    USER_CALENDAR = "SFU_USER_CALENDAR",
    USER_CHATS = "SFU_USER_CHATS",
    PUBLIC_CHANNELS = "SFU_PUBLIC_CHANNELS",
    CHAT_LOADED = "SFU_CHAT_LOADED",
    NEW_CHAT = "SFU_NEW_CHAT",
    CHAT_DELETED = "SFU_CHAT_DELETED",
    CHAT_UPDATED = "SFU_UPDATE_CHAT",
    CONTACT_UPDATED = "SFU_CONTACT_UPDATE",
    CONTACT_INVITE = "SFU_CONTACT_INVITE",
    CONTACT_REMOVED = "SFU_CONTACT_REMOVED",
    GET_USER_LIST = "getUserList",
    GET_USER_CALENDAR = "getUserCalendar",
    ADD_CALENDAR_EVENT = "addCalendarEvent",
    REMOVE_CALENDAR_EVENT = "removeCalendarEvent",
    MUTE_TRACK = "muteTrack",
    SEND_MESSAGE = "sendMessage",
    SEND_CONTROL_MESSAGE = "sendControlMessage",
    MARK_MESSAGE_READ = "markMessageRead",
    MARK_MESSAGE_UNREAD = "markMessageUnread",
    INVITE_CONTACT = "inviteContact",
    REMOVE_CONTACT = "removeContact",
    CONFIRM_CONTACT = "confirmContact",
    ASSIGN_ROLE = "assignRole",
    SUBSCRIBE_TO_WAITING_PARTICIPANT = "subscribeToWaitingParticipant",
    UNSUBSCRIBE_FROM_WAITING_PARTICIPANT = "unsubscribeFromWaitingParticipant",
    MOVE_TO_WAITING_ROOM = "moveToWaitingRoom",
    CONFIGURE_WAITING_ROOM = "configureWaitingRoom",
    TRACK_CONTENT_HEADER = "a=content =",
    GET_USER_CHATS = "getUserChats",
    GET_PUBLIC_CHANNELS = "getPublicChannels",
    LOAD_CHAT = "loadChat",
    CREATE_CHAT = "createChat",
    DELETE_CHAT = "deleteChat",
    RENAME_CHAT = "renameChat",
    ADD_MEMBER_TO_CHAT = "addMemberToChat",
    REMOVE_MEMBER_FROM_CHAT = "removeMemberFromChat",
    UPDATE_CHANNEL_SEND_POLICY = "updateChannelSendPolicy",
    ADD_CHANNEL_SEND_PERMISSION_LIST_MEMBER = "addChannelSendPermissionListMember",
    REMOVE_CHANNEL_SEND_PERMISSION_LIST_MEMBER = "removeChannelSendPermissionListMember",
    ADD_CHAT_TO_FAVOURITES = "addChatToFavourites",
    REMOVE_CHAT_FROM_FAVOURITES = "removeChatFromFavourites"
}
export declare type InternalMessage = {
    type: SfuEvent | RoomEvent | InternalApi;
    roomName: string;
    internalMessageId: string;
};
export declare type OperationFailed = InternalMessage & {
    operation: Operations;
    error: string;
    info: any;
};
export declare type RoomMessage = InternalMessage & {
    message: {
        nickName: string;
        message: string;
    };
};
export declare type FragmentedMessage = {
    id: string;
    last: boolean;
    payload: string;
};
export declare enum RemoteSdpType {
    OFFER = "offer",
    ANSWER = "answer"
}
export declare type RemoteSdp = InternalMessage & {
    info: {
        sdp: string;
        type: RemoteSdpType;
    };
};
export declare type RoleAssigned = InternalMessage & {
    name: string;
    role: ParticipantRole;
};
export declare type CreatedRoom = InternalMessage & {
    inviteId: string;
};
export declare type JoinedRoom = InternalMessage & {
    name: string;
};
export declare type LeftRoom = InternalMessage & {
    name: string;
};
export declare type AddRemoveTracks = InternalMessage & {
    info: {
        nickName: string;
        waitingRoom: boolean;
        info: Array<{
            id: string;
            type: TrackType;
            contentType: string;
            mid: string;
            quality: Array<string>;
            mute: boolean;
        }>;
    };
};
export declare type WaitingRoomUpdate = InternalMessage & {
    enabled: boolean;
};
export declare enum MessageState {
    NO_DELIVERY_NO_READ = "NO_DELIVERY_NO_READ",
    PARTIAL_DELIVERY_NO_READ = "PARTIAL_DELIVERY_NO_READ",
    PARTIAL_DELIVERY_PARTIAL_READ = "PARTIAL_DELIVERY_PARTIAL_READ",
    FULL_DELIVERY_NO_READ = "FULL_DELIVERY_NO_READ",
    FULL_DELIVERY_PARTIAL_READ = "FULL_DELIVERY_PARTIAL_READ",
    FULL_DELIVERY_FULL_READ = "FULL_DELIVERY_FULL_READ"
}
export declare type MessageStatus = {
    id: string;
    chatId: string;
    delivered: boolean;
    state: MessageState;
    lastReadMessageId: string;
    info: string;
    date: number;
};
export declare enum MessageAttachmentType {
    file = "file",
    picture = "picture"
}
export declare type MessageAttachment = {
    type: MessageAttachmentType;
    name: string;
    size: number;
    payload: string;
};
export declare type Message = {
    id: string;
    chatId: string;
    date: number;
    from: string;
    to?: string;
    status: MessageState;
    body: string;
    attachments: Array<MessageAttachment>;
};
export declare type SfuMessageEvent = InternalMessage & {
    message: Message;
};
export declare type MessageStatusEvent = InternalMessage & {
    status: MessageStatus;
};
export declare enum UserState {
    OFFLINE = "OFFLINE",
    ONLINE = "ONLINE"
}
export declare type Invite = InternalMessage & {
    id: string;
    from: string;
    to: string;
};
export declare type User = {
    state: UserState;
    id: string;
    nickname: string;
    confirmed: boolean;
    invite: Invite;
};
export declare type UserListEvent = InternalMessage & {
    list: Array<User>;
};
export declare type ContactInviteEvent = InternalMessage & {
    invite: Invite;
};
export declare type ContactUpdateEvent = InternalMessage & {
    contact: User;
};
export declare type ContactRemovedEvent = InternalMessage & {
    contact: User;
};
export declare type CalendarEvent = {
    id: string;
    accessCode: string;
    description: string;
    title: string;
    start: number;
    end: number;
    ownerVideo: boolean;
    participantVideo: boolean;
    recurring: boolean;
    usePMI: boolean;
    waitingRoom: boolean;
};
export declare type Calendar = {
    events: Array<CalendarEvent>;
};
export declare type UserCalendarEvent = InternalMessage & {
    calendar: Calendar;
};
export declare type UserSpecificChatInfo = {
    id: string;
    favourite: boolean;
    channel: boolean;
    name: string;
    owner: string;
    members: Array<string>;
    lastReadMessageId: string;
    canSend: boolean;
    channelType: ChannelType;
    channelSendPolicy: ChannelSendPolicy;
    sendPermissionList: Array<string>;
};
export declare enum ChannelType {
    PUBLIC = "PUBLIC",
    PRIVATE = "PRIVATE"
}
export declare enum ChannelSendPolicy {
    EVERYONE = "EVERYONE",
    ADMIN = "ADMIN",
    ADMIN_AND_LIST = "ADMIN_AND_LIST"
}
export declare type Chat = {
    id: string;
    name: string;
    owner: string;
    member: string;
    favourite: boolean;
    members: Array<string>;
    messages: Array<Message>;
    channel: boolean;
    channelType: ChannelType;
    channelSendPolicy: ChannelSendPolicy;
    sendPermissionList: Array<string>;
};
export declare type NewChatEvent = InternalMessage & {
    info: UserSpecificChatInfo;
};
export declare type RemovedChatEvent = InternalMessage & {
    info: UserSpecificChatInfo;
};
export declare type UpdateChatEvent = InternalMessage & {
    info: UserSpecificChatInfo;
};
export declare type ChatMap = {
    [key: string]: UserSpecificChatInfo;
};
export declare type ChatsEvent = InternalMessage & {
    chats: ChatMap;
};
export declare type PublicChannelsEvent = InternalMessage & {
    channels: ChatMap;
};
export declare type ChatLoadedEvent = InternalMessage & {
    chat: Chat;
};
export declare type OperationFailedEvent = InternalMessage & {
    operation: Operations;
    error: string;
    info: any;
};
