import { Calendar, ChannelSendPolicy, ChannelType, Chat, ChatMap, InternalMessage, Invite, Message, MessageAttachment, MessageStatus, SfuEvent, State, User, UserSpecificChatInfo } from "./constants";
import { RoomExtended } from "./room-extended";
declare type NotifyUnion = InternalMessage | Message | MessageStatus | Array<User> | Calendar | UserSpecificChatInfo | Invite | User | ChatMap | Chat;
export declare class SfuExtended {
    #private;
    connect(options: {
        url: string;
        username: string;
        password: string;
        nickname: string;
        timeout?: number;
    }): Promise<{
        username: string;
        nickname: string;
        pmi: string;
    }>;
    sendMessage(msg: {
        body: string;
        chatId: string;
        attachments?: Array<MessageAttachment>;
    }): Promise<MessageStatus>;
    markMessageRead(msg: {
        id: string;
        chatId: string;
    }): Promise<MessageStatus>;
    markMessageUnread(msg: {
        id: string;
        chatId: string;
    }): Promise<MessageStatus>;
    getUserList(): Promise<User[]>;
    getUserCalendar(): Promise<Calendar>;
    addCalendarEvent(event: {
        id: string;
        title: string;
        description: string;
        start: number;
        end: number;
        recurring: boolean;
        accessCode: string;
        waitingRoom: boolean;
        usePMI: boolean;
        ownerVideo: boolean;
        participantVideo: boolean;
    }): Promise<void>;
    removeCalendarEvent(event: {
        id: string;
    }): Promise<void>;
    getUserChats(): Promise<ChatMap>;
    getPublicChannels(): Promise<ChatMap>;
    loadChat(chat: {
        id: string;
    }): Promise<Chat>;
    createChat(chat: {
        id?: string;
        name?: string;
        members?: Array<string>;
        favourite?: boolean;
        channel?: boolean;
        channelType?: ChannelType;
        channelSendPolicy?: ChannelSendPolicy;
        sendPermissionList?: Array<string>;
    }): Promise<UserSpecificChatInfo>;
    deleteChat(chat: {
        id: string;
    }): Promise<void>;
    renameChat(chat: {
        id: string;
        name: string;
    }): Promise<void>;
    addMemberToChat(chat: {
        id: string;
        member: string;
    }): Promise<UserSpecificChatInfo>;
    removeMemberFromChat(chat: {
        id: string;
        member: string;
    }): Promise<UserSpecificChatInfo>;
    inviteContact(invite: {
        to: string;
    }): Promise<User>;
    confirmContact(invite: {
        id: string;
        from: string;
        to: string;
    }): Promise<User>;
    removeContact(contact: {
        id: string;
    }): Promise<User>;
    updateChannelSendPolicy(channel: {
        id: string;
        channelSendPolicy: ChannelSendPolicy;
    }): Promise<UserSpecificChatInfo>;
    addChannelSendPermissionListMember(channel: {
        id: string;
        member: string;
    }): Promise<UserSpecificChatInfo>;
    removeChannelSendPermissionListMember(channel: {
        id: string;
        member: string;
    }): Promise<UserSpecificChatInfo>;
    addChatToFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    removeChatFromFavourites(chat: {
        id: string;
    }): Promise<UserSpecificChatInfo>;
    createRoom(options: {
        pc: RTCPeerConnection;
        name: string;
        pin: string;
    }): RoomExtended;
    getRoom(options: {
        name: string;
    }): RoomExtended;
    disconnect(): void;
    user(): {
        username: string;
        nickname: string;
        pmi: string;
    };
    server(): string;
    state(): State;
    on(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
    off(event: SfuEvent, callback: (arg0: NotifyUnion) => void): SfuExtended;
}
export {};
